@@ -133,7 +133,7 @@ init (GnomePilotPDialog *gppd)
 	gppd->priv = priv;
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "PilotSettings");
+	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "PilotSettings", NULL);
 	if (!priv->xml) {
 		g_message ("gnome-pilot-pdialog init(): Could not load the Glade XML file!");
 		goto error;
@@ -166,15 +166,12 @@ gnome_pilot_pdialog_new (GnomePilotClient *gpc, PilotState *state, GPilotPilot *
 	fill_widgets (gppd);
 	init_widgets (gppd);
 
-	gtk_signal_connect (GTK_OBJECT (gpc),
-			    GNOME_PILOT_CLIENT_SIGNAL_COMPLETED_REQUEST (gppd_request_completed), 
-			    gppd);
-	gtk_signal_connect (GTK_OBJECT (gpc),
-			    GNOME_PILOT_CLIENT_SIGNAL_USER_INFO (gppd_userinfo_requested), 
-			    gppd);
-	gtk_signal_connect (GTK_OBJECT (gpc), 
-			    GNOME_PILOT_CLIENT_SIGNAL_SYSTEM_INFO (gppd_system_info_requested), 
-			    gppd);
+	gnome_pilot_client_connect__completed_request (gpc, gppd_request_completed, 
+						       gppd);
+	gnome_pilot_client_connect__user_info (gpc, gppd_userinfo_requested, 
+					       gppd);
+	gnome_pilot_client_connect__system_info (gpc, gppd_system_info_requested, 
+						 gppd);
 	
 	return object;
 }
@@ -295,11 +292,17 @@ gppd_request_completed (GnomePilotClient* client,
 	
 	priv = gppd->priv;
 
-	if (handle != priv->handle1)
+	if (handle == priv->handle1)
+		priv->handle1 = -1;
+	else if (handle == priv->handle2)
+		priv->handle2 = -1;
+	else
 		return;
 
-	gtk_widget_destroy (priv->sync_dialog);
-	priv->sync_dialog = NULL;
+	if (priv->handle1 == -1 && priv->handle2 == -1) {
+		gtk_widget_destroy (priv->sync_dialog);
+		priv->sync_dialog = NULL;
+	}
 }
 
 static void 
@@ -323,12 +326,6 @@ gppd_userinfo_requested (GnomePilotClient *gpc,
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_username), priv->pilot->pilot_username);
 	g_snprintf (buf, sizeof (buf), "%d", priv->pilot->pilot_id);
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_id), buf);
-
-	priv->handle1 = -1;
-	priv->handle2 = -1;
-
-	gtk_widget_destroy (priv->sync_dialog);
-	priv->sync_dialog = NULL;
 }
 
 static void 
@@ -344,12 +341,6 @@ gppd_system_info_requested (GnomePilotClient *gpc,
 	
 	priv->pilot->creation = sysinfo->creation;
 	priv->pilot->romversion = sysinfo->romVersion;
-
-       	priv->handle1 = -1;
-	priv->handle2 = -1;
-
-	gtk_widget_destroy (priv->sync_dialog);
-	priv->sync_dialog = NULL;
 }
 
 
