@@ -172,19 +172,24 @@ fill_conduit_first_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *sta
 	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
 }
 
-void
-show_popup_menu (GtkCList *list, GdkEventButton *event, GtkMenu *menu)
+gboolean
+show_popup_menu (GtkTreeView *treeview, GdkEventButton *event, GtkMenu *menu)
 {
 	if (event && event->button ==3) {
-		gint  row, col;
-		
-		if (gtk_clist_get_selection_info (list, event->x, event->y, &row, &col)) {
-			gtk_clist_select_row (list, row, 0);
-			
+		GtkTreePath *path;
+
+		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path,
+						   NULL, NULL, NULL)) {
+			gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview),
+							path);
+			gtk_tree_path_free (path);
+
 			gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 
 					event->button, event->time);
 		}
 	}
+
+	return FALSE;
 }
 
 void 
@@ -230,7 +235,7 @@ real_choose_pilot_dialog (PilotState *state)
 	GList *tmp;
 	GPilotDevice *dev;
 	
-	xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "ChooseDevice");	
+	xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "ChooseDevice", NULL);
 	dlg = glade_xml_get_widget (xml,"ChooseDevice");
 	option_menu = glade_xml_get_widget (xml, "device_menu");
 
@@ -342,7 +347,7 @@ insert_device_callback (GtkEditable *editable, const gchar *text,
 			gint len, gint *position, void *data)
 {
 	gint i;
-	gchar *curname;
+	const gchar *curname;
 
 	curname = gtk_entry_get_text (GTK_ENTRY (editable));
 	if (*curname == '\0' && len > 0) {
@@ -373,17 +378,6 @@ check_editable (GtkEditable *editable)
 	return test;
 }
 
-gboolean
-check_selection (GtkCList *clist)
-{
-	gboolean test = TRUE;
-
-	if (clist->selection == NULL)
-		test = FALSE;
-
-	return test;
-}
-
 /* find the next "Cradle#" name that is available for use */
 
 static gint compare_device_name (GPilotDevice *device, gchar *name)
@@ -450,7 +444,7 @@ const gchar*
 device_type_to_str (GPilotDeviceType t) 
 {
 	switch (t) {
-	case PILOT_DEVICE_USB_VISOR: return _("Handspring USB");
+	case PILOT_DEVICE_USB_VISOR: return _("USB");
 	case PILOT_DEVICE_IRDA:      return _("IrDA");
 	case PILOT_DEVICE_NETWORK:   return _("Network");
 	default:                     return _("Serial");
@@ -488,7 +482,7 @@ check_device_info (GPilotDevice* device1, GPilotDevice *device2)
 }
 
 gboolean
-check_base_directory (gchar *dir_name)
+check_base_directory (const gchar *dir_name)
 {
 	gboolean ret = TRUE;
 	/* check basedir validity */
@@ -576,7 +570,7 @@ void
 read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 {
 	GtkWidget *id, *name, *pname, *basedir, *menu;
-	gchar *num;
+	const gchar *num;
 	gint pilotid;
 	g_return_if_fail (pilot!= NULL);
 
@@ -605,12 +599,12 @@ read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 }
 
 void
-read_host_config (GtkObject *object, PilotState *state)
+read_host_config (GObject *object, PilotState *state)
 {
 	GtkWidget *entry;
-	gchar *buf;
+	const gchar *buf;
 
-	entry = gtk_object_get_data (GTK_OBJECT (object), "syncpcid_entry");
+	entry = g_object_get_data (G_OBJECT (object), "syncpcid_entry");
 	if (entry) {
 		buf = gtk_entry_get_text (GTK_ENTRY (entry));
 		state->syncPCid = strtol (buf, NULL, 10);
@@ -622,8 +616,7 @@ save_config_and_restart (GnomePilotClient *gpc, PilotState *state)
 {
 	savePilotState (state);
 	/* FORCE the gpilotd to reread the settings */
-	gnome_pilot_client_pause_daemon (gpc);
-	gnome_pilot_client_unpause_daemon (gpc);
+	gnome_pilot_client_restart_daemon (gpc);
 }
 
 void 
