@@ -21,7 +21,7 @@
  *          Robert Mibus
  */
 
-/* $Id: backup_conduit.c,v 1.43 2001/11/05 10:03:22 eskil Exp $ */
+/* $Id: backup_conduit.c,v 1.45 2003/01/26 02:19:51 toshok Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -726,7 +726,7 @@ insert_dir_callback (GtkEditable *editable, const gchar *text,
 		     gint len, gint *position, void *data)
 {
 	gint i;
-	gchar *curname;
+	const gchar *curname;
 
 	curname = gtk_entry_get_text(GTK_ENTRY(editable));
 	if (*curname == '\0' && len > 0) {
@@ -895,24 +895,19 @@ conduit_load_gpilot_conduit (GPilotPilot *pilot)
 			    "configuration",
 			    cfg);
 
-	gtk_signal_connect (retval, 
-			    GNOME_PILOT_CONDUIT_BACKUP_SIGNAL_BACKUP (gnome_real_pilot_conduit_backup_backup), 
-			    cfg);
-	gtk_signal_connect (retval, 
-			    GNOME_PILOT_CONDUIT_BACKUP_SIGNAL_RESTORE (gnome_real_pilot_conduit_backup_restore),
-			    cfg);
-	gtk_signal_connect (retval, 
-			    GNOME_PILOT_CONDUIT_SIGNAL_CREATE_SETTINGS_WINDOW (create_settings_window), 
-			    NULL);
-	gtk_signal_connect (retval, 
-			    GNOME_PILOT_CONDUIT_SIGNAL_DISPLAY_SETTINGS (display_settings), 
-			    NULL);
-	gtk_signal_connect (retval, 
-			    GNOME_PILOT_CONDUIT_SIGNAL_SAVE_SETTINGS (save_settings), 
-			    NULL);
-	gtk_signal_connect (retval, 
-			    GNOME_PILOT_CONDUIT_SIGNAL_REVERT_SETTINGS (revert_settings), 
-			    NULL);
+	gnome_pilot_conduit_backup_connect__backup (retval, gnome_real_pilot_conduit_backup_backup, 
+					    cfg);
+	gnome_pilot_conduit_backup_connect__restore (retval, gnome_real_pilot_conduit_backup_restore, 
+					     cfg);
+	gnome_pilot_conduit_connect__create_settings_window (retval, create_settings_window, 
+							    NULL);
+	gnome_pilot_conduit_connect__display_settings (retval, display_settings, 
+						      NULL);
+	gnome_pilot_conduit_connect__save_settings (retval, save_settings, 
+						   NULL);
+	gnome_pilot_conduit_connect__revert_settings (retval, revert_settings, 
+						     NULL);	
+
 	return GNOME_PILOT_CONDUIT (retval);
 }
 
