@@ -119,14 +119,32 @@ static int
 pilot_connect (GPilotDevice *device,int *error) 
 {
 	struct pi_sockaddr addr;
-	int sd, listen_sd;
+	int sd, listen_sd, pf;
 	int ret;
     
 	if (device->type != PILOT_DEVICE_NETWORK) {
 		pilot_set_baud_rate (device);
 	}
 
-	if (!(listen_sd = pi_socket (PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_DLP))) {
+	switch (device->type) {
+	case PILOT_DEVICE_SERIAL:
+		pf = PI_PF_PADP;
+		break;
+	case PILOT_DEVICE_USB_VISOR:
+		pf = PI_PF_NET;
+		break;
+	case PILOT_DEVICE_IRDA:
+		pf = PI_PF_PADP;
+		break;
+	case PILOT_DEVICE_NETWORK:
+		pf = PI_PF_NET;
+		break;
+	default:
+		pf = PI_PF_DLP;
+		break;
+	}
+	
+	if (!(listen_sd = pi_socket (PI_AF_PILOT, PI_SOCK_STREAM, pf))) {
 		g_warning ("pi_socket: %s",strerror (errno));
 		if (error) *error = 1;
 		return -1;
@@ -141,7 +159,7 @@ pilot_connect (GPilotDevice *device,int *error)
 	so don't really need to do it again here.
 */
 	if (device->type == PILOT_DEVICE_NETWORK) {
-		device->port = ".";
+		device->port = "net:any";
 	}
 
 	strcpy (addr.pi_device,device->port);
@@ -815,6 +833,7 @@ network_device_err (GIOChannel *io_channel,
 static const char *product_names[] =
 {
 	"Handspring Visor",
+	"Handspring Treo",
 	"Palm Handheld",
 	NULL
 };
@@ -982,7 +1001,7 @@ sig_int_handler (int dummy) {
 /* This deletes the ~/.gpilotd.pid file */
 void 
 remove_pid_file () {
-	gchar *home_directory;
+	const gchar *home_directory;
 	gchar *pid_file;
 
 	home_directory=g_get_home_dir ();
@@ -1036,7 +1055,7 @@ write_pid_file ()
 	} else {
 		g_warning (_("Unable to find home directory for uid %d"),geteuid ());
 	}
-	if (g_file_test (queue_dir, G_FILE_TEST_ISDIR)==FALSE) {
+	if (g_file_test (queue_dir, G_FILE_TEST_IS_DIR)==FALSE) {
 		if (mkdir (queue_dir, 0700)) {
 			g_warning (_("Unable to create file installation queue directory"));
 		}
@@ -1088,11 +1107,6 @@ dump_build_info ()
 #ifdef WITH_VFS
 	str = g_string_append (str, "[VFS] ");
 #endif
-#ifdef USING_OAF
-	str = g_string_append (str, "[OAF] ");
-#else
-	str = g_string_append (str, "[GOAD] ");
-#endif
 #ifdef WITH_USB_VISOR
 	str = g_string_append (str, "[USB] ");
 #endif
@@ -1122,13 +1136,14 @@ main (int argc, char *argv[])
 	g_message ("%s %s starting...",PACKAGE,VERSION);
 	dump_build_info ();
 
-
+	gnome_init (PACKAGE, VERSION, argc, argv);
+	
 	/* Setup the correct gpilotd.pid file */
 	remove_pid_file ();
 	write_pid_file ();
 
 	/* Init corba and context, this call also loads the config into context */
-	gtk_type_init ();
+	g_type_init ();
 	gpilotd_corba_init (&argc,argv,&context);
 
 	reread_config=FALSE;	
